/* --------------------------------------------------------------- */
/*                    Participant Selection                        */
/* --------------------------------------------------------------- */
di "Number of Participants"
count if uid != .
count if q11 == "Female"
count if q11 == "Male"
di "Academic year"
count if q9 == "Freshman"
count if q9 == "Sophomore"
count if q9 == "Junior"
count if q9 == "Senior"
/* BUGBUG - How do classify the remaining 4 participants?  Lookup */


/* --------------------------------------------------------------- */
/*                    Login Task Participants                      */
/* --------------------------------------------------------------- */
di "Number of participants"
count if recalled_tsk != .
count if recalled_tsk != . & q11 == "Female"
count if recalled_tsk != . & q11 == "Male"
di "Brought Memory Aid"
count if broughtaid == 1
count if broughtlaptop == 1
count if broughtlaptop == 0

/* --------------------------------------------------------------- */
/*                    Login Task Participants                      */
/* --------------------------------------------------------------- */
di "Sites where participant indicated they used"
/* Do not count sites participants indicated they did not have an account */
gen overcounts_tmp = overcounts 
replace overcounts_tmp = 0 if overcounts_tmp == .
gen webCountP1_ = ( numwebsitestask - overcounts_tmp )
summarize webCountP1_
centile webCountP1_
gen webCountP2_ = ( numwebsitestask - overcounts_tmp + numcategories + numsites )
summarize webCountP2_
centile webCountP2_
drop overcounts_tmp

/* Successful logins */
summarize numsuccesstask
centile numsuccesstask

/* Fraction of sites covered by laboratory exercise */
tabulate percentcovered
tabulate families_tsk
/* BUGBUG how to compare the size of the largest family to the number of repeated passwords?!! */
centile related_tsk

/* Footnote, university sites */
summarize princetonldap
centile princetonldap

/**** Pass Two ****/
summarize families_all
centile families_all



/* --------------------------------------------------------------- */
/*                       Reuse Rates                               */
/* --------------------------------------------------------------- */

/* Compute how often passwords are reused across multiple websites */
gen reuse1_ = numsuccesstask / families_tsk
gen reuse2_ = ( numsuccesstask + numcategories + numsites ) / families_all
/* Summary statistics of reuse rates */
summarize reuse1_ reuse2_
centile reuse1_ reuse2_

/* Detect effect of using a memory aid in experiment */
gen aid_ = (broughtlaptop | broughtaid)
oneway reuse1_ aid
di "Effect size = " %5.2f = 1 * r(F) / (1* r(F) + 2 * (r(N) - 1))
quietly summarize reuse1_ if aid == 0
local m1 = r(mean)
local sd1 = r(sd)
local n1 = r(N)
quietly summarize reuse1_ if aid == 1
local m2 = r(mean)
local sd2 = r(sd)
local n2 = r(N)
quietly sampsi `m1' `m2', alpha(.05) n1(`n1') n2(`n2') sd1(`sd1') sd2(`sd2')
di "Power = " %5.2f = r(power)

oneway reuse2_ aid
di "Effect size = " %5.2f = 1 * r(F) / (1* r(F) + 2 * (r(N) - 1))
quietly summarize reuse2_ if aid == 0
local m1 = r(mean)
local sd1 = r(sd)
local n1 = r(N)
quietly summarize reuse2_ if aid == 1
local m2 = r(mean)
local sd2 = r(sd)
local n2 = r(N)
quietly sampsi `m1' `m2', alpha(.05) n1(`n1') n2(`n2') sd1(`sd1') sd2(`sd2')
di "Power = " %5.2f = r(power)


/* Reuse rate correlated with the number of websites used */
/* WRONG - use (# success - # overcounts) 
gen accounts1_ = numsuccesstask
gen accounts2_ = numsuccesstask + numcategories + numsites
*/
corr reuse1_ webCountP1_
corr reuse2_ webCountP2_

reg reuse1_ webCountP1_
reg reuse2_ webCountP2_

/* Plot of reuse ratio and the number of online accounts in second pass */

/************************************************************/
/*                          WARNING                         */
/************************************************************/
/* double check thre regression coefficients before printing the caption!! */
twoway (scatter reuse2_ webCountP2_) (lfit reuse2_ webCountP2_), ytitle(Reuse Ratio, size(large)) yscale(outergap(r)) xtitle(Number of Websites, size(large)) graphregion(fcolor(white)) caption("r^2 = 0.31, Reuse Ratio = 0.49 + 0.26 * NumWebsites", size(large)) legend(off)

gen college_yr = 1 if q9 == "Freshman"
replace college_yr = 2 if q9 == "Sophomore"
replace college_yr = 3 if q9 == "Junior"
replace college_yr = 4 if q9 == "Senior"

robvar webCountP2_, by(college_yr)
oneway webCountP2_ college_yr, tabulate
oneway families_all college_yr, tabulate


collapse (mean) meanwebcount = webCountP2_ (sd) sdwebcount = webCountP2_ (count) n = webCountP2_, by(college_yr)

gen hiwebcount = meanwebcount + invttail(n-1, 0.025) *(sdwebcount/sqrt(n))
gen lowebcount = meanwebcount - invttail(n-1, 0.025) *(sdwebcount/sqrt(n))
twoway (bar meanwebcount college_yr, fintensity(inten20) barwidth(.9) ) (rcap hiwebcount lowebcount college_yr if college_yr >= 1 & college_yr <= 4), xtitle("College Year") xlabel( 1 "Freshman" 2 "Sophomore" 3 "Junior" 4 "Senior") ytitle("Number of Online Accounts") legend(off) graphregion(fcolor(white)) yscale(range(0))

