#!/bin/sh

######################################################################
# Generate a Do-File to import and merge data
######################################################################
export INF=`ls | grep *-DumpSurvey.txt`
export DATE=`date '+%d%b'`
echo "Creating stata file for questionnaire data..."

echo "**********************************************************************" >> "$DATE.do"
echo "* Create stata file for responses to online questionnaire" >> "$DATE.do"
echo "**********************************************************************" >> "$DATE.do"
echo "insheet using \"$INF\", tab" >> "$DATE.do"
echo "do \"DoFiles/Questionnaire/VariableLabels.do\"" >> "$DATE.do"
echo "do \"DoFiles/Questionnaire/QuestionnaireCodebook.do\"" >> "$DATE.do"
echo "sort uid" >> "$DATE.do"
echo "preserve" >> "$DATE.do"
echo "save \"$DATE-DumpSurvey.dta\"" >>"$DATE.do"
echo "drop *" >> "$DATE.do"

export INF=`ls | grep *-estimations.txt`
echo "**********************************************************************" >> "$DATE.do"
echo "* Create stata file for responses to self-reported password estimates" >> "$DATE.do"
echo "**********************************************************************" >> "$DATE.do"
echo "insheet using \"$INF\", tab" >> "$DATE.do"
echo "do \"DoFiles/Estimates/EstimationsFix.do\"" >> "$DATE.do"
echo "do \"DoFiles/Estimates/Estimations-Recode.do\"" >> "$DATE.do"
echo "sort uid" >> "$DATE.do"
echo "save \"$DATE-Estimates.dta\"" >> "$DATE.do"
echo "drop *" >> "$DATE.do"

export INF=`ls | grep *-login.txt`
echo "**********************************************************************" >> "$DATE.do"
echo "* Create stata file for log of login successes and failures" >> "$DATE.do"
echo "**********************************************************************" >> "$DATE.do"
echo "insheet using \"$INF\", tab" >> "$DATE.do"
echo "sort uid" >> "$DATE.do"
echo "save \"$DATE-Login.dta\"" >> "$DATE.do"
echo "drop *" >> "$DATE.do"

export INF=`ls | grep *-use.txt`
echo "**********************************************************************" >> "$DATE.do"
echo "* Create stata file for log number of sites used" >> "$DATE.do"
echo "**********************************************************************" >> "$DATE.do"
echo "insheet using \"$INF\", tab" >> "$DATE.do"
echo "sort uid" >> "$DATE.do"
echo "save \"$DATE-Use.dta\"" >> "$DATE.do"
echo "drop *" >> "$DATE.do"

export INF=`ls | grep *-Aids.txt`
echo "**********************************************************************" >> "$DATE.do"
echo "* Create stata file for noting if participant used helpers " >> "$DATE.do"
echo "**********************************************************************" >> "$DATE.do"
echo "insheet using \"$INF\", tab" >> "$DATE.do"
echo "sort uid" >> "$DATE.do"
echo "save \"$DATE-Aids.dta\"" >> "$DATE.do"
echo "drop *" >> "$DATE.do"

export INF=`ls | grep *-AdditionalSites.txt`
echo "**********************************************************************" >> "$DATE.do"
echo "* Create stata file for recording additionally recalled sites" >> "$DATE.do"
echo "**********************************************************************" >> "$DATE.do"
echo "insheet using \"$INF\", tab" >> "$DATE.do"
echo "sort uid" >> "$DATE.do"
echo "save \"$DATE-AdditionalSites.dta\"" >> "$DATE.do"
echo "drop *" >> "$DATE.do"

export INF=`ls | grep *-Overcounts.txt`
echo "**********************************************************************" >> "$DATE.do"
echo "* Create stata file for recording unsuccessful logs b/c didn't actually have an account" >> "$DATE.do"
echo "**********************************************************************" >> "$DATE.do"
echo "insheet using \"$INF\", tab" >> "$DATE.do"
echo "sort uid" >> "$DATE.do"
echo "save \"$DATE-Overcounts.dta\"" >> "$DATE.do"
echo "drop *" >> "$DATE.do"


echo "**********************************************************************" >> "$DATE.do"
echo "* Merge all of the datasets into a single dataset" >> "$DATE.do"
echo "**********************************************************************" >> "$DATE.do"
echo "use \"$DATE-DumpSurvey.dta\"" >> "$DATE.do"
echo "merge uid using \"$DATE-Estimates.dta\" \"$DATE-Login.dta\" \"$DATE-Use.dta\" \"$DATE-Aids.dta\" \"$DATE-AdditionalSites.dta\" \"$DATE-Overcounts.dta\"" >> "$DATE.do"
echo "save \"$DATE.dta\"" >> "$DATE.do"

echo "Creating stata file..."
echo "stata -b \"do $DATE.do\""
stata -b "do $DATE.do"
echo "  output $DATE-DumpSurvey.dta"
echo "  output $DATE-Estimations.dta"
echo "  output $DATE-Login.dta"
echo "  output $DATE-Use.dta"
echo "  output $DATE-Aids.dta"
echo "  output $DATE-AdditionalSites.dta"
echo "  output $DATE-Overcounts.dta"
echo "  ...completed."
