#!/usr/local/bin/perl -w

use CGI qw/:standard/;
use strict;

require UID;
my $taskFile = "-task.dat";

######################################################################
# collectLoginStats
######################################################################
# Records whether or not a participant was successful at logging
# into a website
sub printAndCollectLoginStats(\$ \$) { 
	my ($uidRef, $fileRef) = @_;

	if(-f $$fileRef) {
		open(INFH, "<$$fileRef") || die ("Cannot open $$fileRef");
		my @taskLogs = <INFH>;
		close(INFH);

		chomp(@taskLogs);

		my @prev_line = (0, "", "", "", "", "", "");

		my %timeOuts = ();
		my %successes = ();
		my %fails = ();
		my %tasks = ();
		foreach (@taskLogs) {
			next if (/^(\s*)$/);

			# Entries are in the format
			# TIMEOUT|uid|siteIndex|successBit|@errors|otherBit|otherReasonsText
			my ($timeoutBit, $uid, $site, $successBit, $errors, $otherBit, $reasons) = @prev_line;
			if( ($uid, $site) = /^TIMEOUT\|(\d+)\|(\d+)\|\|\|\|\|$/ ) {
				# Count the number of times you used a timeout
				$timeoutBit = 1;
				$timeOuts{$site} = 1;
				#print "$_\n";
			} elsif( ($uid, $site, $successBit, $errors, $otherBit, $reasons) = /^\|(\d+)\|(.*)\|(y|n)\|((website|username|password|e-mail|typo|\s)*)\|(.*)\|(.*)/ ) {
				$timeoutBit = 0;

				# if the site-id is not a number (BUG in original script)
				# the prior line should be a timeout, so use this to record
				# the log of the task success
				if($prev_line[0] > 0 && $site =~ /^SCALAR/) {
					$site = $prev_line[2];
				}

				# Count the number of times you successfully logged in
				if($successBit eq "y") {
					$successes{$site} = 1;
				} else {
					$fails{$site} = 1;
				}


				# Beware of multiple submissions, the site-ids should be unique
				# given that I don't really know how to handle double 
				# submissions assume the last one was the correct submission
				
				# print "$_\n";
				
			} else {
				print STDERR "REJECT = $_\n";
			}


			# my $numTimeout = $#(keys $timeOuts);
			@prev_line = ($timeoutBit, $uid, $site, $successBit, $errors, $otherBit, $reasons);
		}

		{
			my @keys = keys(%successes);
			my $numSuccess = $#keys + 1; 
			@keys = keys(%fails);
			my $numFail = $#keys + 1;
			@keys = keys(%timeOuts);
			my $numTimeout = $#keys + 1;
			print "$$uidRef\t$numSuccess\t$numFail\t$numTimeout\n";
		}
	}
}

######################################################################
# main
######################################################################
{
    my $dir = $UID::dir;
    my @UID = UID::collectUIDs(\$dir);

    print "UID\tNumSuccessTask\tNumFailTask\tNumTimeoutTask\n";
    foreach my $uid (@UID) {
	my $responseDir = "$UID::dir/$uid";
	my $file = "$responseDir/$uid$taskFile";
	printAndCollectLoginStats($uid, $file);	
    }
}
