# $dir holds the data for each participant, where the participant's
# data is in a seperate subdirectory
$dir = "/u/sgaw/public_html/restricted/responses/completed";
$mixedFile = "-mixed.dat";
$taskFile = "-task.dat";
$descriptiveFile = "-descriptives.dat";
$policyFile = "-policy.dat";

######################################################################
# collectUIDs
######################################################################
sub collectUIDs(\$) {
	my ($d) = @_;
	opendir(DIR, $$d) || die ("Cannot open directory $$d");


# Collect the UIDs for all people who completed the quantification
# part of the survey
	my @UID = ();
	foreach my $direntry(readdir(DIR)) {
		next if $direntry eq ".";
		next if $direntry eq "..";

		if (-d "$dir/$direntry") {
			push(@UID, $direntry);
		}
	}
	closedir(DIR);
	return @UID;
}

######################################################################
# collectSiteUseAndPopularity
######################################################################
# All websites checked by the user, but only unique ones, mixed so the order
# is randomized
# Collect how many unique websites each participant uses
sub collectSiteUseAndPopularity(\$ \$ \% \%) { 
	my ($uidRef, $fileRef, $infoRef, $popularityRef) = @_;

	if(-f $$fileRef) {
		open(INFH, "<$$fileRef") || die ("Cannot open $$fileRef");
		my @websiteTriplets = <INFH>;
		close(INFH);

		chomp(@websiteTriplets);

		foreach (@websiteTriplets) {
			
			# Entries are in the format (title, URL, index, doneBit)
			if( /^\((.*), (.*), (\d+), 1\)/ ) {
				if( defined $popularityRef->{$3} ) {
					my ($title, $URL, $hits) = @{$popularityRef->{$3}};
					$popularityRef->{$3} = [$title, $URL, ++$hits];
				} else {
					$popularityRef->{$3} = [$1, $2, 1];
				}
				$infoRef->{$$uidRef}->{'NumSites'}++;
			} else {
				print STDERR "-*- Participant $$uidRef did not finish site $1, $3 -*-\n";
			}
		}
		print "$$uidRef\t$infoRef->{$$uidRef}->{'NumSites'}\n";
	}
}

######################################################################
# collectLoginStats
######################################################################
# Records whether or not a participant was successful at logging
# into a website
sub collectLoginStats(\$ \$ \%) { 
	my ($uidRef, $fileRef, $infoRef) = @_;

	if(-f $$fileRef) {
		open(INFH, "<$$fileRef") || die ("Cannot open $$fileRef");
		my @taskLogs = <INFH>;
		close(INFH);

		chomp(@taskLogs);

		my @prev_line = (0, "", "", "", "", "", "");

		my %timeOuts = ();
		my %successes = ();
		my %fails = ();
		my %tasks = ();
		foreach (@taskLogs) {
			next if (/^(\s*)$/);

			# Entries are in the format
			# TIMEOUT|uid|siteIndex|successBit|@errors|otherBit|otherReasonsText
			my ($timeoutBit, $uid, $site, $successBit, $errors, $otherBit, $reasons) = @prev_line;
			if( ($uid, $site) = /^TIMEOUT\|(\d+)\|(\d+)\|\|\|\|\|$/ ) {
				# Count the number of times you used a timeout
				$timeoutBit = 1;
				$timeOuts{$site} = 1;
				#print "$_\n";
			} elsif( ($uid, $site, $successBit, $errors, $otherBit, $reasons) = /^\|(\d+)\|(.*)\|(y|n)\|((website|username|password|e-mail|typo|\s)*)\|(.*)\|(.*)/ ) {
				$timeoutBit = 0;

				# if the site-id is not a number (BUG in original script)
				# the prior line should be a timeout, so use this to record
				# the log of the task success
				if($prev_line[0] > 0 && $site =~ /^SCALAR/) {
					$site = $prev_line[2];
				}

				# Count the number of times you successfully logged in
				if($successBit eq "y") {
					$successes{$site} = 1;
				} else {
					$fails{$site} = 1;
				}


				# Beware of multiple submissions, the site-ids should be unique
				# given that I don't really know how to handle double 
				# submissions assume the last one was the correct submission
				
				# print "$_\n";
				
			} else {
				print STDERR "REJECT = $_\n";
			}


			# my $numTimeout = $#(keys $timeOuts);
			@prev_line = ($timeoutBit, $uid, $site, $successBit, $errors, $otherBit, $reasons);
		}

		{
			my @keys = keys(%successes);
			my $numSuccess = $#keys + 1; 
			@keys = keys(%fails);
			my $numFail = $#keys + 1;
			@keys = keys(%timeOuts);
			my $numTimeout = $#keys + 1;
			print "$$uidRef\t$numSuccess\t$numFail\t$numTimeout\n";
		}
	}
}

######################################################################
# collectPasswordEstimationStats
######################################################################
# Records the estimate number of passwords and also how often they 
# are reused
# Estimates the number of passwords for a participant
sub collectPasswordEstimationStats(\$ \$ \%) { 
	my ($uidRef, $fileRef, $infoRef) = @_;

	if(-f $$fileRef) {
		open(INFH, "<$$fileRef") || die ("Cannot open $$fileRef");
		@entries = <INFH>;
		close(INFH);

		chomp(@entries);

		my @additionalSites = ();
		my @savedEntries = ();

		foreach (@entries) {
			next if (/^(\s*)$/);

			# Get rid of carriage returns
			if(/\r/) {
				s/\r/\n/g;
			}
			chomp($_);
			
			if( my ($uid, $taskBit, $numRecalled, $numFamilies, $largestSize,
					$smallestSize, $numRepeated, $numRelated, $percentage)
				= /^(\d+)\|(|1)\|(.*)\|(.*)\|(.*)\|(.*)\|(.*)\|(.*)\|(|\d+-\d+)$/ ) {
				my @array = ($uid, $numRecalled, $numFamilies,
							 $largestSize, $smallestSize, $numRepeated,
							 $numRelated, $percentage);
				my $index = ($taskBit eq "1") ? 0 : 1;
				# Note: double submissions will have "last write saved"
				$savedEntries[$index] = \@array;
			} else {
				# Addtional websites used by people, collect these for later
				my $tmp = $_;

				if(/^\D.*,/) {				# Some use comma-seperated values
					# (Ignore if it was the start of a numerical list)
					my @temp = split(/,\s*/);
					foreach (@temp) {
						next if(/^etc/);
						push(@additionalSites, $_);
					}
				} elsif(/(www)(.*)(www)/) { # Some use whitespace
					my @temp = split(/\s+/);
					foreach (@temp) {
						next if(/^etc/);
						push(@additionalSites, $_);
					}
				}else { # Some use newlines
					# Remove list (1., 2., 3.) values
					if(/^\d\./) {
						my $tmp;
						($tmp, $_) = /^(\d\.)(.*)/;
					}
					push(@additionalSites, $_);
				}
			}
		} #end loop of @entries

		# Put everything into one array for tab-delimited printouts
		{
			my @tmp = @{$savedEntries[1]};
			{ my $tmp = shift(@tmp); }
			my @store = @{$savedEntries[0]};
			splice(@store, $#store + 1, $#tmp, @tmp);
			my $printout = join("\t", @store);
			print "$printout\n";
			return (@store, @additionalSites);
		}

	}
}

######################################################################
# collectPolicyChoices
######################################################################
# What participants rank as stronger passwords, although the question 
# and entry order was randomized, the printouts have a standard format
sub collectPolicyChoices(\$ \$ \%) { 
	my ($uidRef, $fileRef, $infoRef) = @_;

	if(-f $$fileRef) {
		open(INFH, "<$$fileRef") || die ("Cannot open $$fileRef");
		@entries = <INFH>;
		close(INFH);

		chomp(@entries);

		open(OUTFH, ">$$uidRef.out") || die ("Cannot open $$uidRef.out");
		foreach (@entries) {
			next if (/^(\s*)$/);

			my @temp = split(/\t/, $_);
			if(defined $temp[4]) {
				print OUTFH "$temp[0]:\n1) $temp[1]\n2) $temp[2]\n3) $temp[3]\n$temp[4]\n\n";
			} else {
				print OUTFH "$temp[0]\n";
			}
		}
		close(OUTFH);
	}
}



######################################################################
# main
######################################################################
{
	my @UID = collectUIDs($dir);

	my %userInfo = (); 
	my %sitePopularity = ();

	foreach $uid (@UID) {
		my $responseDir = "$dir/$uid";
		#print STDERR "======================================================================\n";
		#print STDERR "$uid\n";
		my $file = "$responseDir/$uid$mixedFile";
		collectSiteUseAndPopularity($uid, $file, %userInfo, %sitePopularity);
		$file = "$responseDir/$uid$taskFile";
		collectLoginStats($uid, $file, %userInfo);
		$file = "$responseDir/$uid$descriptiveFile";
		my (@estimations, @addSites) = collectPasswordEstimationStats($uid, $file, %userInfo);
		$file = "$responseDir/$uid$policyFile";
		collectPolicyChoices($uid, $file, %userInfo);
	}

	
}



