#!/usr/local/bin/perl -w

use CGI qw/:standard/;
use strict;

require UID;
my $descriptiveFile = "-descriptives.dat";

######################################################################
# collectPasswordEstimationStats
######################################################################
# Records the estimate number of passwords and also how often they 
# are reused
# Estimates the number of passwords for a participant
sub collectPasswordEstimationStats(\$ \$) { 
    my ($uidRef, $fileRef) = @_;

    if(-f $$fileRef) {
	open(INFH, "<$$fileRef") || die ("Cannot open $$fileRef");
	my @entries = <INFH>;
	close(INFH);

	chomp(@entries);

	my @additionalSites = ();
	my @savedEntries = ();

	foreach (@entries) {
	    next if (/^(\s*)$/);

	    # Get rid of carriage returns
	    if(/\r/) {
		s/\r/\n/g;
	    }
	    chomp($_);

	    if( my ($uid, $taskBit, $numRecalled, $numFamilies, $largestSize,
		    $smallestSize, $numRepeated, $numRelated, $percentage)
		= /^(\d+)\|(|1)\|(.*)\|(.*)\|(.*)\|(.*)\|(.*)\|(.*)\|(|\d+-\d+)$/ ) {
		my @array = ($uid, $numRecalled, $numFamilies,
			     $largestSize, $smallestSize, $numRepeated,
			     $numRelated, $percentage);
		my $index = ($taskBit eq "1") ? 0 : 1;
		# Note: double submissions will have "last write saved"
		$savedEntries[$index] = \@array;
	    } else {
		# Addtional websites used by people, collect these for later
		my $tmp = $_;

		if(/^\D.*,/) {				# Some use comma-seperated values
		    # (Ignore if it was the start of a numerical list)
		    my @temp = split(/,\s*/);
		    foreach (@temp) {
			next if(/^etc/);
			push(@additionalSites, $_);
		    }
		} elsif(/(www)(.*)(www)/) { # Some use whitespace
		    my @temp = split(/\s+/);
		    foreach (@temp) {
			next if(/^etc/);
			push(@additionalSites, $_);
		    }
		}else { # Some use newlines
		    # Remove list (1., 2., 3.) values
		    if(/^\d\./) {
			my $tmp;
			($tmp, $_) = /^(\d\.)(.*)/;
		    }
		    push(@additionalSites, $_);
		}
	    }
	} #end loop of @entries

	# Put everything into one array for tab-delimited printouts
	{
	    my @tmp = @{$savedEntries[1]};
	    { my $tmp = shift(@tmp); }
	    my @store = @{$savedEntries[0]};
	    splice(@store, $#store + 1, $#tmp, @tmp);
	    my $printout = join("\t", @store);
	    print "$printout\n";
	    return (@store, @additionalSites);
	}

    }
}

######################################################################
# main
######################################################################
{
    my $dir = $UID::dir;
    my @UID = UID::collectUIDs(\$dir);

    print "UID\tNumRecalledTask\tNumFamiliesTask\tNumLargestTask\tNumSmallestTask\tNumRepeatedTask\tNumRelatedTask\tPercentCovered\tNumRecalledAll\tNumFamiliesAll\tNumLargestAll\tNumSmallestAll\tNumRepeatedAll\tNumRelatedAll\n";
    foreach my $uid (@UID) {
	my $responseDir = "$UID::dir/$uid";
	my $file = "$responseDir/$uid$descriptiveFile";
	my (@estimations, @addSites)
	    = collectPasswordEstimationStats($uid, $file);
    }
}
