#!/usr/local/bin/perl -w
######################################################################
# GenerateLogins.cgi
######################################################################
#
# Generate webpages that present links to websites that users indicated
# they have accounts.  Question if the user was successfully able to
# login.
# 
use strict;
use warnings;

alarm(60); # initiate a self-destruction after 60 secs

use CGI;
use DataManip;

######################################################################
# record_last_task
######################################################################
sub record_last_task(\$) {
    my ($query_ref) = @_;
    my $query = $$query_ref;

    my $site_index = $query->param('site');
    if(defined($site_index)) {


		my $success = "n";
		if($query->param('success_radio')) {
			$success = $query->param('success_radio');
		}
		my @errors = $query->param('errors_check');
		my $other_chk = $query->param('other_check');
		my $other_txt = $query->param('other_text');
		my $id = $query->param('id');
		my $timeout = $query->param('timeout');


		open(OUT, ">>responses/$id-task.dat");
		if(defined($timeout)) {
			print OUT "TIMEOUT|$id|$site_index|||||\n";
		} else {
			print OUT "|$id|$site_index|$success|@errors|$other_chk|$other_txt\n";
		}
		close(OUT);
    }
}


######################################################################
# display_task
######################################################################
sub display_task(\$ \$ \$ \$ \$ \$ \$) {
    my ($num_tasks_completed, $total_tasks_ref, $title_ref, $url_ref, $index_ref, $id_ref, $timedOut_ref) = @_;


    my $query = CGI::->new();
    # Remove all previous parameters (though maybe we should be keeping
    # the default "sticky" state
    $query->delete_all();
    print $query->CGI::header();
    print $query->CGI::start_html("Success with Logins"), "\n";


    print $query->CGI::h1("$$title_ref Tryout"), "\n";
    {
		## BUGBUG $$index_ref is global index, not local to the
		# count of how many sites that are tasks
		my $page_num = $$num_tasks_completed + 1;
		print $query->CGI::h2("Part 2 of 4, Page $page_num of $$total_tasks_ref");
    }

    if($$timedOut_ref) {
		print "The 90 seconds has passed.  Before we move on to the next task,";
		print " could you please select some reasons why it was difficult to ";
		print "login successfully in 90 seconds for this website?\n";
    } else {
		# Setup a timeout period
		print "<meta HTTP-EQUIV=\"REFRESH\" content=\"90;url=GenerateLogins.cgi\?id=$$id_ref&timeout=true&site=$$index_ref\">";
		print $query->CGI::p();
		print "Login to the $$title_ref website.  Use the link below which ";
		print "opens a new browser window.  You will have 90 seconds to try ";
		print "to login to the website.  When you have finished, close the ";
		print "$$title_ref window to return to this webpage.\n";
		print $query->CGI::center($query->CGI::a( {'-href' => "$$url_ref",
												   '-target' => "_blank"},
												  "$$url_ref")), "\n";

		print $query->CGI::p(), "\n";

    }

    print $query->CGI::start_form('-method' => 'POST',
								  '-action' => 'GenerateLogins.cgi');

    unless($$timedOut_ref) {

		my $success_radio = $query->CGI::radio_group('-name' => 'success_radio',
													 '-values' => ['y', 'n'],
													 '-default' => '-',
													 '-labels' => {'y' => "Yes",
																   'n' => 'No'});
		
		
		print "Were you able to login to the website on your first attempt?\n";
		print $query->CGI::p(), "\n", $success_radio, "\n";
		print $query->CGI::p(), "\n";
		print "If had a successful login, please write down your password for the $$title_ref website.\n";
		print $query->CGI::p(), "\n";
		print "If you were not able to login successfully, what ";
		print "are some reasons why you believe you were not successful?\n";
    }

    my $err_lbls = {'website' => "Couldn't access the website",
					'username' => "Forgot my username for this website",
					'password' => "Forgot my password for this website",
					'e-mail' => "Forgot my e-mail address for this website",
					'typo' => "Made a typographical error in entering the login data"
					};
    my $errors_group = $query->CGI::checkbox_group('-name' => 'errors_check',
												   '-values' => ['website',
																 'username',
																 'password',
																 'e-mail',
																 'typo'],
												   '-linebreak' => 'true',
												   '-labels' => $err_lbls);

    print $query->CGI::p(), $errors_group;
    print $query->CGI::checkbox('-name' => 'other_check',
								'-value' => 'selected',
								'-label' => 'Other (please specify): ');
    print $query->CGI::textfield('-name' => 'other_text',
								 '-default' => ''), "\n", $query->CGI::p();
    print $query->CGI::submit(-value => "Go to next step"), "\n";
    print "<input type=hidden name=\"site\" value=\"$$index_ref\">\n";
    print "<input type=hidden name=\"id\" value=\"$$id_ref\">\n";
    print $query->CGI::end_form();
    print $query->CGI::end_html(), "\n";
}

######################################################################
# retreive_site
######################################################################
# $ret_val  array reference (title, url, websiteIndex, doneBit, total tasks,
#                            number of tasks completed)
sub retreive_site(\$ \$) {
    my ($id_ref, $site) = @_;
    my $ret_val;
    my @files = ("responses/$$id_ref-mixed.dat");

    open(RW_F, "+<$files[0]") || die("Unable to open file $files[0] $!");
    my @output = ();

	my $doneCount = 0;
    while(<RW_F>) {
		my $line = $_;
		if(/^\((.*), (.*), $$site, (.*)\)/) {
			# Now signal we've finished with this one
			$line = "($1, $2, $$site, 1)\n";
			$ret_val = [$1, $2, $site];
		}

		if(/^\((.*), (.*), (.*), 1\)/) {
			$doneCount++;
		}

		push(@output, $line);
    }
    push(@$ret_val, 1 + $#output);
	push(@$ret_val, $doneCount);

    seek(RW_F, 0, 0);
    ## BUGBUG Need file permissions for writing
    foreach (@output) {
		print RW_F $_;
    }
    close(RW_F);
    return $ret_val;
}



######################################################################
# next_site
######################################################################
# Return value is undefined if there is no websites that the user
# hasn't seen
# $ret_val  array reference (title, url, websiteIndex, doneBit, total tasks,
#                            number of tasks completed)
sub next_site(\$ \$) {
    my ($id_ref, $site) = @_;
    my $ret_val;
    my @files = ("responses/$$id_ref-mixed.dat");
    my @output = ();

    # Get the next website by finding the first line with a not !done bit
    # set (title, url, done)
    open(RW_F, "+<$files[0]") || die("Unable to open file $files[0] $!");

	my $doneCount = 0;
    while(<RW_F>) {
		my $line = $_;

		if(defined($$site)) {
			# Format is (title, url, index, doneBit)
			if(/^\((.*), (.*), $$site, 0\)/) {
				# Now signal we've finished with this one
				$line = "($1, $2, $$site, 1)\n";
				# and fix us up while we continue to search
				# for a new one
				$_ = $line;
			}
		}

		if(/^\((.*), (.*), (.*), 0\)/) {
			$ret_val = [$1, $2, $3];
		} else {
			$doneCount++;
		}
		push(@output, $line);
    }

	if(defined($ret_val)) {
		push(@$ret_val, 1 + $#output);
		push(@$ret_val, $doneCount);
	}

    seek(RW_F, 0, 0);
    ## BUGBUG Need file permissions for writing
    foreach (@output) {
		print RW_F $_;
    }
    close(RW_F);
    return $ret_val;
}

######################################################################
# main
######################################################################
package main;

# Startup a log with a specific participant's information
my $query = CGI->new();

if($query->param('id')) {
    # Verify ID is one of the accepted ones before moving on
    my $id = $query->param('id');
    my $retval = id_ok($id);
    if ( $retval != 1 ) {
		my $msg = "ID number $id is not recognized.";
		display_error_page($msg);
		exit;
    }

    # unless((-s "responses/$id-mixed.dat") > 1) {
    if ($query->param('doRemix')) {
		# Randomize the websites
		resort_websites($id);
    } else {
        record_last_task($query);
    }
    
    my $site = $query->param('site');
    my $timedOut;
    if($query->param('timeout')) {
		$timedOut = 1;
    } else {
		$timedOut = 0;
    }


    my $finished = 1;
    my $web_ref;

    if($timedOut) {
		$web_ref = retreive_site($id, $site);
    } else {
		$web_ref = next_site($id, $site);
    }

    if(defined($web_ref)) {
		$finished = 0;
    }

    if($timedOut) {
		$finished = 0;
    }

    unless($finished) {
		display_task($web_ref->[4], $web_ref->[3], $web_ref->[0],
					 $web_ref->[1], $web_ref->[2], $id, $timedOut);
    } else {
		print CGI::header(), CGI::start_html();
		print "<meta HTTP-EQUIV=\"REFRESH\" content=\"0;url=SummaryStats.cgi\?id=$id\">";

		print CGI::end_html();
    }

} else {		
	my $msg = "No ID information.";
	display_error_page($msg);
}
# Display the website & ask the user to login & indicate if successful

# Write down the responses

# Move on to the next website

# Display the questionnaire

