#!/usr/local/bin/perl -w
use CGI qw/:standard/;
use strict;
use Fcntl ':flock'; # use LOCK_* constants for file locking
use DataManip;

alarm(60); # initiate a self-struction after 60 seconds

######################################################################
# randomize_array
######################################################################
# Randomize the order of items in this array
sub randomize_array(\@) {
    my ($array_ref) = @_;
    for(my $j = 0; $j < $#$array_ref + 1; $j++) {
	my $k = int(rand($#$array_ref + 1));
	my $tmp = $array_ref->[$j];
	$array_ref->[$j] = $array_ref->[$k];
	$array_ref->[$k] = $tmp;
    }
}

######################################################################
# print_questions
######################################################################
sub print_questions(\@) {
    my ($questions_ref) = @_;
    my @questions = @$questions_ref;
    my @passwords = ();
    print "<ol>\n";
    for(my $i = 0; $i < $#questions + 1; $i++) {
	my ($label, $tip) = split(/\t/, $questions[$i]->[0]);
	print "<li>$tip\n";

	print "<p><table border=1>\n";
	print "<tr>\n";
	# Print the possible passwords
	for(my $j = 0; $j < 3; $j++) {
	    my ($a, $e) = split(/\t/, $questions[$i]->[1 + $j]);
	    print "<td width=25%><center><pre>$a</pre></center></td>\n"; 
	}        
	print "</tr>\n";
	print "<tr>\n";
	# Print the explanation of the password construction
	for(my $j = 0; $j < 3; $j++) {
	    my ($a, $e) = split(/\t/, $questions[$i]->[1 + $j]);
	    print "<td width=25%>$e</td>\n"; 
	}
	print "</tr>";
	print "</table>\n";

	# Now print the form widgets for seleting the ranking
	# and writing an explanation
	my @choices = ("");
	for(my $j = 0; $j < 3; $j++) {
	    my ($a, $e) = split(/\t/, $questions[$i]->[1 + $j]);
	    push(@choices, $a);
	}
	my @places = ("First (Most secure)", "Second", "Third (Least secure)");

	print CGI::h4("Ranking");
	print "<table>\n";
	for(my $j = 0; $j < 3; $j++) {
	    print "<tr><td>$places[$j]\n</<td>";
	    my $option = CGI::popup_menu(-name => "$label-$j",
					 -values => \@choices,
					 -default => "");
	    print "<td>$option</td></tr>\n";
	}
	print "</table>\n";
	print CGI::h4("Explanation");
	print CGI::textarea(-name=>"$label-text",
			    -rows=> "5",
			    -columns=> "100");

	print "</li>\n";
	print "<p>\n";
    }
    print "</ol>\n";
}

######################################################################
# main
######################################################################
my $file = "./PolicyLogic2.txt";

# Startup a log with a specific participant's information
my $query = CGI->new();

if($query->param('id')) {
    # Verify ID is one of the accepted ones before moving on
    my $id = $query->param('id');
    my $retval = id_ok($id);
    if ( $retval != 1 ) {
		my $msg = "ID number $id is not recognized.";
		display_error_page($msg);
		exit;
    }

    open(INFH, "<$file") || die("Unable to open $file: $!");
    my @input = <INFH>;
    close(INFH);
    my @questions = ();
    # File is in the format line1 = label\tquestion; 
    # line2,3,4 = answers (tab delimited)
    for(my $i = 0; $i + 4 <= $#input; $i = $i + 4) {
	if($i % 4 == 0) {
	    my @answers = ($input[$i+1], $input[$i+2], $input[$i+3]);
	    # Randomize the answers
	    randomize_array(@answers);
	    chomp($input[$i]);
	    push(@questions, [$input[$i], $answers[0], $answers[1], $answers[2]]);
	}
    }

# Now randomize the questions
    randomize_array(@questions);

# Now create the webpage for asking the questions
    print CGI::header();
    print CGI::start_html('-title' => "Policy Logic Questions");
    print CGI::start_form('-method' => 'POST',
			  '-action' => 'Processor-Policy.cgi');

    print CGI::h1("Selecting Passwords");
    print CGI::p(), "Many websites have tips and rules for creating strong passwords.  Pretend your friend Eve Jones (evjones\@princeton.edu) is also a student at Princeton and she is having trouble understanding these rules.  For each rule or tip, she's provided three example passwords with an explanation of how she created her password.  Help her learn what makes a strong password by ranking her examples from strongest to weakest and explaining your ranking.";

    print_questions(@questions);

    print "<input type=\"hidden\" name=\"id\" value=\"$id\" />\n";

    print CGI::submit('-name' => 'submit', '-value' => 'Submit'), "\n";
    print CGI::end_form(), "\n";
    print CGI::end_html(), "\n";
} else {
    my $title = "Policy Logic Questions";
    my $url = "PolicyScript.cgi";
    display_login($title, $url);
}
