#!/usr/local/bin/perl -w
######################################################################
# SummaryStats.cgi
######################################################################
#
# Ask the user to compute abstract information on their passwords
#
use strict;
use warnings;

alarm(60); # initiate a self-destruction after 60 secs

use CGI;
use DataManip;

######################################################################
# record_summary
######################################################################
sub record_summary(\$) {
  my ($query_ref) = @_;
  my $query = $$query_ref;

  my $recall = $query->param('RECALL');
  my $id = $query->param('id');
  my $percentage = $query->param('PERCENT_SITES');
  my $other_sites = $query->param('OTHER_SITES');
  my $passwords = $query->param('NUM_PASSWORDS');
  my $family = $query->param('NUM_FAMILIES');
  my $largest = $query->param('LARGEST_FAMILY');
  my $smallest = $query->param('SMALLEST_FAMILY');
  my $repeat = $query->param('NUM_REPETITIONS');
  my $related = $query->param('NUM_RELATED');
  
  open(OUT, ">>responses/$id-descriptives.dat");
  print OUT "$id|$recall|$passwords|$family|$largest|$smallest|$repeat|$related|$percentage\n";
  print OUT "$other_sites\n";
  close(OUT);
}

######################################################################
# print_goodbye
######################################################################
sub print_goodbye() {
    print <<'_PAGEEND_';
Content-Type: text/html; charset=ISO-8859-1

<html>

<head>
<title>Thank You</title>
</head>

<body>

<h1>Thank you for participating in this study.</h1>
<p>Your participations is helping us understand more about selection and recall
of passwords for online accounts.&nbsp; If you have any questions about this
study, please contact Shirley Gaw <a href="mailto:sgaw@cs.princeton.edu">sgaw@cs.princeton.edu</a>.
</p>

</body>

</html>
_PAGEEND_
}

######################################################################
# print_form
######################################################################
sub print_form(\$ \$ \$) {
    my ($query_ref, $id_ref, $represent_ref) = @_;
    my $query = $$query_ref;

    print $query->CGI::header();
    print $query->CGI::start_html("Report Password Statistics"), "\n";

    print "<h1>Summary of Login Attempts</h1>\n";

    print "<form method=\"POST\" action=\"SummaryStats.cgi\">\n";
    # Ask about the fraction of sites we hit in this survey
    if($$represent_ref) {
	# Print out all the websites where users indicated they were and were
	# not successful at logging in
	open(MIXED_TASKS, "<responses/$$id_ref-mixed.dat") || die ("Unable to open $$id_ref-mixed.dat: $!");
	print "Below is a list of websites which you indicated you have web accounts: <br>\n";
	print "<ul>";
	while(<MIXED_TASKS>) {
	    if(/^(.(.*), (.*), (.*), (.*))/) {
		print "<li> $2\n";
	    }
	}
	print "</ul>\n";
	close(MIXED_TASKS);

	print << '_REP_END_';
<p>This list is a sample of websites where you have online accounts.
  <ul>
    <li>1. Think of all of the other websites you visit that have login accounts. What percentage of your websites does this sample represent?
    <p><input type="radio" name="PERCENT_SITES" Value="0-24">0 - 24%
    <br><input type="radio" name="PERCENT_SITES" Value="25-49">25 - 49%
    <br><input type="radio" name="PERCENT_SITES" Value="50-74">50 - 74%
    <br><input type="radio" name="PERCENT_SITES" Value="75-100">75- 100%
    </p>
    </li>
    <li>2. Please list other websites where you have online accounts (ie, websites where you need to login with a username and password):
    <p><TEXTAREA name="OTHER_SITES" rows="10" cols="80"></TEXTAREA></p>
    </li>
  </ul>
  <input type=hidden name="RECALL" value="1">
_REP_END_
} else {
    # Ask the user to recall all other passwords.
    print "The previous questions may have missed some of the passwords you use.  Now write down all of your other passwords that you can recall and answer the questions below.  Please use any tools (memory, e-mail archives, pieces of paper, etc) that will help you recall your passwords.";
    print "<input type=hidden name=\"FINISHED\" value=\"1\">\n";

}

    open(IN, "<SummaryPage.txt") || die("Unable to open SummaryPage.txt for reading:$!");
    while(<IN>) {
	print $_;
    }
    close(IN);
    print "<input type=hidden name=\"id\" value=\"$$id_ref\">\n";
    print "</form>\n";
    print $query->CGI::end_html();
}

######################################################################
# main
######################################################################
package main;

my $query = CGI->new();

if($query->param('id')) {
    # Verify ID is one of the accepted ones before moving on
    my $id = $query->param('id');
    my $retval = id_ok($id);
    if ( $retval != 1 ) {
	my $msg = "ID number $id is not recognized.";
	display_error_page($msg);
	exit;
    }

    if(defined($query->param('NUM_PASSWORDS'))) {
	record_summary($query);
    }

    if(defined($query->param('FINISHED'))) {
	print_goodbye();
    } else {
	# Have we asked the user about the fraction of websites
	# the survey represented?
	my $represent = 1;
	if(defined($query->param('RECALL'))) {
	    $represent = 0;
	}
	print_form($query, $id, $represent);
    }


} else { 
    my $msg = "No ID information.";
    display_error_page($msg);
}
