#!/usr/local/bin/perl -w
######################################################################
# UsageData.cgi
######################################################################
#
# CGI script to collect info on which websites the user has
# accoutns
#
# Depends DataManip to parse the websites.txt file 
#
use strict;
use warnings;

alarm(60); # initiate a self-destruction after 60 secs

use CGI;
use DataManip;

my $HTML_TITLE = "Survey of Online Password Selection and Management";

######################################################################
# show_websites_by_category
######################################################################
# $web_ref  database of all websites
# $index    index of the current category of websites
# $cat_ref  reference to the current category's websites
# $uid_ref  the participant's id
sub show_websites_by_category(\% \$ \$ \$) {

    my ($web_ref, $index, $cat_ref, $uid_ref) = @_;

    # Retreive all websites in the ith category
    my $category = $$cat_ref;
    my $cat_websites_ref = $web_ref->{$category};

    my %labels = ('yes' => "Yes", 'no' => "No");

  
    print CGI::header();
    print CGI::start_html('-title' => $HTML_TITLE), "\n";
    print CGI::h1("Category: $category"), "\n";    
    {
	my @categories = (keys %$web_ref);
	my $num_categories = 1 + $#categories;
	my $step_num = 1 + $$index;
	print CGI::h2("Part 1 of 4, Page $step_num of $num_categories");
    }

    print "Please answer as accurately as possible.\n", CGI::p();
    print "Do you have an account on the following websites?  ";
    print "Place a check next the website name.", CGI::p(), "\n";
    print CGI::start_form('-method' => 'POST',
			  '-action' => 'UsageData.cgi'), "\n";


    my @group = ();
    for my $title (sort keys %$cat_websites_ref) {
		push(@group, $title);
    }

    print CGI::checkbox_group(-name => "$category",
			      -values => \@group,
			      -rows => $#group + 1,
			      -columns => 1);
    print CGI::p(), "\n";


    # Use hidden field to track which category we've already seen
	$$index = $$index + 1;
	print "<input type=\"hidden\" name=\"categoryIndex\" value=\"$$index\"  />";
	print "<input type=\"hidden\" name=\"id\" value=\"$$uid_ref\"  />";
    print CGI::submit('-name' => 'title_submit',
		      '-value' => 'Submit'), "\n";
    print CGI::end_form();
    print CGI::end_html(), "\n";
}


######################################################################
# main
######################################################################
package main;

# Startup a log with a specific participant's information
my $query = CGI->new();

if($query->param('id')) {
    # Verify ID is one of the accepted ones before moving on
    my $id = $query->param('id');
    my $retval = id_ok($id);
    if ( $retval != 1 ) {
		my $msg = "ID number $id is not recognized.";
		display_error_page($msg);
		exit;
    }

	# Use a hidden field to submit which categories we've views
	my $categoryIndex = 0;
	if($query->param('categoryIndex')) {
	    $categoryIndex = $query->param('categoryIndex');
	} 

	# Read the database of websites
	my %websites = read_database();

    my @categories = (keys %websites);
    my $num_cat = $#categories + 1;

    # Write out the answers from the last submission
    my $curr_category = $categories[$categoryIndex];
    if($categoryIndex > 0) {
	# Show all websites within a category asking if they've used it or not
	my $prev_category = $categories[$categoryIndex - 1];
	my @values = $query->param($prev_category);
	record_submission($id, $prev_category, @values, %websites);
    }

    if($categoryIndex < $num_cat) {
	show_websites_by_category(%websites, $categoryIndex,
				  $curr_category, $id);
    } else {
	# Randomize the websites selected by the user & write to server log
	print CGI::header();
	print CGI::start_html();
	print "<meta HTTP-EQUIV=\"REFRESH\" content=\"0;url=GenerateLogins.cgi\?id=$id\&doRemix=1\">";
	print CGI::end_html();
    }    
} else {
    my $url = "UsageData.cgi";
    display_login($HTML_TITLE, $url);
}



