using System;
using System.Drawing;
using System.Collections;
using mshtml;

namespace PrivacyGuard.ConfirmationToolkit
{
	/// <summary>
	/// Summary description for RecipientArea.
	/// </summary>
	public class RecipientArea : System.Windows.Forms.Panel
	{
		private ConfirmationDialog myparent;
		private ArrayList entries;

		public const int AREAW = 280;
		public const int AREAH = 280;
		public const int ENTRYX = 5;
		public const int ENTRYY = 5;

		private RecipientEntry selected;
		public RecipientEntry Selected 
		{
			get 
			{
				return this.selected;
			}
		}
		private RecipientEntry current;
		public RecipientEntry Current
		{
			get 
			{
				return this.current;
			}
		}

		public class RecipientEntry : System.Windows.Forms.Panel 
		{
			public const int WIDTH = 245;
			public const int HEIGHT = 30;

			private System.Windows.Forms.RadioButton radiobutton;
			public const int RBX = 0;
			public const int RBY = 10;
			public const int RBW = 10;
			public const int RBH = 10;
			public System.Windows.Forms.RadioButton Radiobutton 
			{
				get 
				{
					return this.radiobutton;
				}
			}

			private System.Windows.Forms.Label domain;
			public const int DOMX = 15;
			public const int DOMY = 0;
			public const int DOMW = 160;
			public const int DOMH = 15;
			private string domainname;
			public string Domainname 
			{
				get 
				{
					return this.domainname;
				}
			}

			private System.Windows.Forms.LinkLabel description;
			public const int DESX = 15;
			public const int DESY = 15;
			public const int DESW = 230;
			public const int DESH = 15;
			private string despstr;

			private System.Windows.Forms.PictureBox rating;
			public const int RATX = 180;
			public const int RATY = 2;
			public const int RATW = 65;
			public const int RATH = 12;
			private string imageuri;

			public RecipientEntry(string dom, string desp, string uri) 
			{
				this.domainname = dom;
				this.despstr = desp;
				this.imageuri = uri;

				InitializeComponent();
			}

			private void InitializeComponent() 
			{
				this.Size = new Size(WIDTH, HEIGHT);
				this.radiobutton = new System.Windows.Forms.RadioButton();
				this.radiobutton.Location = new Point(RBX, RBY);
				this.radiobutton.Size = new Size(RBW, RBH);
				this.radiobutton.Text = "";
				this.radiobutton.Click += new EventHandler(entry_Click);

				this.domain = new System.Windows.Forms.Label();
				this.domain.Location = new Point(DOMX, DOMY);
				this.domain.Size = new Size(DOMW, DOMH);
				this.domain.Text = this.domainname;
				this.domain.Font = new Font(this.domain.Font.Name, this.domain.Font.Size, FontStyle.Bold);
				this.domain.Click += new EventHandler(entry_Click);

				this.description = new System.Windows.Forms.LinkLabel();
				this.description.Location = new Point(DESX, DESY);
				this.description.Size = new Size(DESW, DESH);
				this.description.Text = this.despstr;
				this.description.Font = new Font(this.description.Font.Name, this.description.Font.Size, FontStyle.Italic);

				this.rating = new System.Windows.Forms.PictureBox();
				this.rating.Location = new Point(RATX, RATY);
				this.rating.Size = new Size(RATW, RATH);
				this.rating.Image = Image.FromFile(this.imageuri);
				this.rating.Click += new EventHandler(entry_Click);

				this.Controls.Add(this.radiobutton);
				this.Controls.Add(this.domain);
				this.Controls.Add(this.description);
				this.Controls.Add(this.rating);
			}

			private void entry_Click(object sender, System.EventArgs e) 
			{
				(this.Parent as RecipientArea).SelectEntry(this);
			}
			public RecipientEntry CopyEntry() 
			{
				return new RecipientEntry(this.domainname, this.despstr, this.imageuri);
			}
		}

		public RecipientArea(ConfirmationDialog d)
		{
			this.myparent = d;
			this.entries = new ArrayList();
			this.InitializeComponent();
		}

		private void InitializeComponent() 
		{
			IEBrowser b = myparent.Browser;
			//string domainname = PrivacyGuardUtils.IEUtil.GetDomainName((b.BrowsingWindow.Document as IHTMLDocument2).url);
			string domainname = b.GetDomainName(false);
			ArrayList al = new ArrayList();
			bool includedomain = false;
			Object[] ha = b.History.ToArray();
			for (int i = 0; i < ha.Length; i++) 
			{
				string dom = ((BackEndImpl.History.HistoryEntry) ha[i]).Domain;
				if (domainname.Equals(dom))
					includedomain = true;
				al.Add(b.ReputationEvaluator.GetReputationRecord(dom));
			}
			if (!includedomain)
				al.Add(b.ReputationEvaluator.GetReputationRecord(domainname));

			// randomize entries
//			Random rng = new Random();
//			for (int j = entries.Count-1; j > 0; j--) 
//			{
//				int swap_j = rng.Next(j+1);
//				if (swap_j != j) 
//				{
//					object tmp = entries[swap_j];
//					entries[swap_j] = entries[j];
//					entries[j] = tmp;
//				}
//			}

			this.Size = new Size(AREAW, AREAH);
			this.BackColor = Color.White;
			this.AutoScroll = true;

			int y = ENTRYY;
			bool addbkcolor = false;
			for (int i = 0; i < al.Count; i++) 
			{
				BackEndImpl.ReputationEvaluator.ReputationRecord record = (BackEndImpl.ReputationEvaluator.ReputationRecord) al[i];
				RecipientEntry re = new RecipientEntry(record.Domain, record.Description, record.GetRatingImage());
				this.entries.Add(re);
				if (domainname.Equals(re.Domainname))
					this.current = re;
				re.Location = new Point(ENTRYX, y);
				re.BackColor = addbkcolor ? Color.LightGray : Color.White;
				this.Controls.Add(re);
				y += RecipientEntry.HEIGHT;
				addbkcolor = !addbkcolor;
			}
		}

		public void SelectEntry(RecipientEntry e) 
		{
			(this.Parent.Parent as ConfirmationDialog).ClearWarning();
			this.selected = e;
			IEnumerator ienum = this.entries.GetEnumerator();
			while (ienum.MoveNext()) 
			{
				RecipientEntry c = (RecipientEntry) ienum.Current;
				c.Radiobutton.Checked = (c.Equals(e));
			}
		}
	}
}
