using System;
using System.Drawing;
using System.Windows.Forms;
using System.Collections;

namespace PrivacyGuard.UserStudyToolkit
{
	/// <summary>
	/// Summary description for EmailInbox.
	/// </summary>
	public class EmailInbox : System.Windows.Forms.Panel
	{
		public const int FIXEDY = 250;
		public const float FONTSIZE = 8.25F;
		public const string FONTNAME = "Microsoft Sans Serif";

		public class EmailEntry : System.Windows.Forms.Panel 
		{
			private System.Windows.Forms.Label from;
			private System.Windows.Forms.Label subject;
			private System.Windows.Forms.Label date;
			private System.Windows.Forms.Label size;

			private EmailInbox inbox;
			private string emailurl;

			private bool read = false;

			public EmailEntry(EmailInbox p, string url, string subjectstr, string datestr) 
			{
				this.inbox = p;
				this.emailurl = url;

				this.Size = new System.Drawing.Size(1000, 20);
				this.BackColor = System.Drawing.Color.White;

				this.from = new Label();
				this.subject = new Label();
				this.date = new Label();
				this.size = new Label();

				this.from.Location = new System.Drawing.Point(42, 0);
				this.from.Size = new System.Drawing.Size(300, 20);
				this.from.Text = "John Smith <john_smith_1170@hotmail.com>";
				this.from.TextAlign = ContentAlignment.MiddleLeft;
//				this.from.Font = new Font(this.from.Font.Name,
//					this.from.Font.Size, 
//					FontStyle.Bold, 
//					GraphicsUnit.Point);
				this.from.Font = new Font(FONTNAME,
					FONTSIZE, 
					FontStyle.Bold, 
					GraphicsUnit.Point);
				this.from.MouseMove += new MouseEventHandler(this.entry_MouseMove);
				this.from.Click += new EventHandler(this.entry_Click);

				this.subject.Location = new System.Drawing.Point(342, 0);
				this.subject.Size = new System.Drawing.Size(340, 20);
				this.subject.Text = subjectstr;
				this.subject.TextAlign = ContentAlignment.MiddleLeft;
//				this.subject.Font = new Font(this.subject.Font.Name,
//					this.subject.Font.Size, 
//					FontStyle.Bold, 
//					GraphicsUnit.Point);
				this.subject.Font = new Font(FONTNAME,
					FONTSIZE, 
					FontStyle.Bold, 
					GraphicsUnit.Point);
				this.subject.MouseMove += new MouseEventHandler(this.entry_MouseMove);
				this.subject.Click += new EventHandler(this.entry_Click);

				this.date.Location = new System.Drawing.Point(682, 0);
				this.date.Size = new System.Drawing.Size(258, 20);
				this.date.Text = datestr;
				this.date.TextAlign = ContentAlignment.MiddleLeft;
//				this.date.Font = new Font(this.date.Font.Name,
//					this.date.Font.Size, 
//					FontStyle.Bold, 
//					GraphicsUnit.Point);
				this.date.Font = new Font(FONTNAME,
					FONTSIZE, 
					FontStyle.Bold, 
					GraphicsUnit.Point);
				this.date.MouseMove += new MouseEventHandler(this.entry_MouseMove);
				this.date.Click += new EventHandler(this.entry_Click);

				this.size.Location = new System.Drawing.Point(940, 0);
				this.size.Size = new System.Drawing.Size(19, 20);
				this.size.Text = "2k";
				this.size.TextAlign = ContentAlignment.MiddleLeft;
//				this.size.Font = new Font(this.size.Font.Name,
//					this.size.Font.Size, 
//					FontStyle.Bold, 
//					GraphicsUnit.Point);
				this.size.Font = new Font(FONTNAME,
					FONTSIZE, 
					FontStyle.Bold, 
					GraphicsUnit.Point);
				this.size.MouseMove += new MouseEventHandler(this.entry_MouseMove);
				this.size.Click += new EventHandler(this.entry_Click);

				this.Controls.Add(this.from);
				this.Controls.Add(this.subject);
				this.Controls.Add(this.date);
				this.Controls.Add(this.size);
			}

			private void entry_Click(object sender, System.EventArgs e) 
			{
				if (!read) 
				{
					read = true;
					this.from.Font = new Font(this.from.Font.Name,
						this.from.Font.Size, 
						FontStyle.Italic, 
						GraphicsUnit.Point);
					this.subject.Font = new Font(this.subject.Font.Name,
						this.subject.Font.Size, 
						FontStyle.Italic, 
						GraphicsUnit.Point);
					this.date.Font = new Font(this.date.Font.Name,
						this.date.Font.Size, 
						FontStyle.Italic, 
						GraphicsUnit.Point);
					this.size.Font = new Font(this.size.Font.Name,
						this.size.Font.Size, 
						FontStyle.Italic, 
						GraphicsUnit.Point);
				}
				this.inbox.UpdateFocus(this);
				this.inbox.GotoEmail(this.emailurl);
			}

			private void entry_MouseMove(object sender, System.Windows.Forms.MouseEventArgs e) 
			{
				Cursor.Current = Cursors.Hand;
			}

			public void FocusDisplay(bool focus) 
			{
				Color bg;
				Color fg;
				if (focus) 
				{
					bg = System.Drawing.Color.Blue;
					fg = System.Drawing.Color.White;
				} 
				else 
				{
					bg = System.Drawing.Color.White;
					fg = System.Drawing.Color.Black;
				}

				this.BackColor = bg;
				this.from.ForeColor = fg;
				this.subject.ForeColor = fg;
				this.date.ForeColor = fg;
				this.size.ForeColor = fg;
			}
		}

		private System.Windows.Forms.PictureBox header;
		private System.Windows.Forms.Panel emaillist;

		private string currentEmailurl;

		private string image_uri = @"C:\VisualStudio\PrivacyGuard\images\userstudy\inbox_header.png";

		private IEBrowser browser;
		public EmailInbox(IEBrowser b)
		{
			this.browser = b;
			InitializeComponent();
			DisplayEmails();
		}
		private void InitializeComponent() 
		{
			this.Size = new Size(IEBrowser.MAXIMIZEDX, FIXEDY);

			header = new System.Windows.Forms.PictureBox();
			emaillist = new System.Windows.Forms.Panel();

			this.header.Location = new System.Drawing.Point(0, 0);
			this.header.Size = new System.Drawing.Size(997, 48);
			this.header.Image = System.Drawing.Image.FromFile(image_uri);
			this.emaillist.Location = new System.Drawing.Point(0, 48);
			this.emaillist.Size = new System.Drawing.Size(this.Width, this.Height-48);
			this.emaillist.BackColor = System.Drawing.Color.White;
			this.emaillist.AutoScroll = true;
			this.emaillist.BorderStyle = BorderStyle.Fixed3D;

			this.Controls.Add(this.emaillist);
			this.Controls.Add(this.header);
		}
	
		private void DisplayEmails() 
		{
			EmailStorage es = new EmailStorage();
			this.currentEmailurl = es.DefaultEmailUrl;

			ArrayList emails = es.Emails;
			int y = 0;
			for (int i = 0; i < emails.Count; i++) 
			{
				EmailStorage.Email e = (EmailStorage.Email)emails[i];
				EmailEntry ee = new EmailEntry(this, e.Emailuri, e.Subject, e.Date);
				ee.Location = new Point(0, y);
				this.emaillist.Controls.Add(ee);
				y += ee.Height;
			}
		}

		public void GotoEmail(string url) 
		{
			this.currentEmailurl = url;
			GotoCurrentEmail();
		}
		public void GotoCurrentEmail() 
		{
			this.browser.GotoUrl(this.currentEmailurl);
		}

		public void UpdateFocus(EmailEntry ee) 
		{
			IEnumerator ienum = this.emaillist.Controls.GetEnumerator();
			while (ienum.MoveNext()) 
			{
				EmailEntry c = (EmailEntry) ienum.Current;
				c.FocusDisplay(c == ee);
			}
		}
	}
}
