using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

namespace PrivacyGuard.WebWallet
{
	/// <summary>
	/// Summary description for SiteDescriptionBox.
	/// </summary>
	public class SiteReportBox : System.Windows.Forms.Form
	{
		public class SiteDescription : System.Windows.Forms.Panel 
		{
			public const int WIDTH = 300;

			private System.Windows.Forms.Label domain;
			private System.Windows.Forms.Label nodescription;
			private System.Windows.Forms.PictureBox sslIcon;
			private System.Windows.Forms.Label sslDescription;
			private System.Windows.Forms.PictureBox reputeIcon;
			private System.Windows.Forms.Label regTime;
			private System.Windows.Forms.Label regHost;
			private System.Windows.Forms.Label PopDescription;
			private System.Windows.Forms.PictureBox certIcon;
			private System.Windows.Forms.Label certDescription;

			private string title;
			private BackEndImpl.ReputationEvaluator.ReputationRecord record;

			public SiteDescription(string d, BackEndImpl.ReputationEvaluator.ReputationRecord r) 
			{
				this.title = d;
				this.record = r;
				InitializeComponent();
			}

			private void InitializeComponent() 
			{
				this.domain = new Label();
				this.nodescription= new Label();
				this.sslIcon = new PictureBox();
				this.sslDescription = new Label();
				this.reputeIcon = new PictureBox();
				this.regTime = new Label();
				this.regHost = new Label();
				this.PopDescription = new Label();
				this.certIcon = new PictureBox();
				this.certDescription = new Label();

				this.domain.Location = new Point(0, 0);
				this.domain.Size = new Size(WIDTH, 25);
				this.domain.Text = this.title;
				this.domain.Font = new Font(WebWalletInterface.FONTNAME, 10, FontStyle.Bold);
				this.domain.TextAlign = ContentAlignment.MiddleCenter;

				if (this.record == null) 
				{
					this.nodescription.Location = new Point(0, 30);
					this.nodescription.Size = new Size(WIDTH, 15);
					this.nodescription.Text = "No site report available";
					this.nodescription.Font = new Font(WebWalletInterface.FONTNAME, this.nodescription.Font.Size);
					this.nodescription.TextAlign = ContentAlignment.MiddleCenter;
					this.nodescription.ForeColor = Color.Red;

					this.Controls.Add(this.nodescription);
					this.Size = new Size(WIDTH, 50);
				}
				else 
				{
					this.sslIcon.Location = new Point(5, 30);
					this.sslIcon.Size = new Size(32, 32);
					this.sslDescription.Location = new Point(45, 30);
					this.sslDescription.Size = new Size(WIDTH-45, 35);
					this.sslDescription.Font = new Font(WebWalletInterface.FONTNAME, this.sslDescription.Font.Size);
					this.sslDescription.TextAlign = ContentAlignment.MiddleLeft;
					if (this.record.Ssl) 
					{
						this.sslIcon.Image = Image.FromFile(@"C:\VisualStudio\PrivacyGuard\images\sitereport\lock.gif");
						this.sslDescription.Text = "This site is secured with SSL technology.";
					}
					else 
					{
						this.sslIcon.Image = Image.FromFile(@"C:\VisualStudio\PrivacyGuard\images\sitereport\nonlock.gif");
						this.sslDescription.Text = "This site is NOT secured. The data transmission with this site is NOT protected.";
						this.sslDescription.ForeColor = Color.Red;
					}

					this.reputeIcon.Location = new Point(5, 75);
					this.reputeIcon.Size = new Size (32, 32);
					if (this.record.Reputed)
						this.reputeIcon.Image = Image.FromFile(@"C:\VisualStudio\PrivacyGuard\images\sitereport\globel-small.gif");
					else
						this.reputeIcon.Image = Image.FromFile(@"C:\VisualStudio\PrivacyGuard\images\sitereport\globel-small-gray.gif");

					this.regTime.Location = new Point(45, 70);
					this.regTime.Size = new Size(WIDTH-45, 15);
					this.regTime.Font = new Font(WebWalletInterface.FONTNAME, this.regTime.Font.Size);
					this.regTime.TextAlign = ContentAlignment.MiddleLeft;
					this.regTime.Text = this.record.Regtime;
					if (this.record.AlertTime)
						this.regTime.ForeColor= Color.Red;

					this.regHost.Location = new Point(45, 85);
					this.regHost.Size = new Size(WIDTH-45, 15);
					this.regHost.Font = new Font(WebWalletInterface.FONTNAME, this.regHost.Font.Size);
					this.regHost.TextAlign = ContentAlignment.MiddleLeft;
					this.regHost.Text = this.record.Host;

					this.PopDescription.Location = new Point(45, 100);
					this.PopDescription.Size = new Size(WIDTH-45, 15);
					this.PopDescription.Font = new Font(WebWalletInterface.FONTNAME, this.PopDescription.Font.Size);
					this.PopDescription.TextAlign = ContentAlignment.MiddleLeft;
					this.PopDescription.Text = this.record.Pop;
					if (this.record.AlertPop)
						this.PopDescription.ForeColor= Color.Red;

					this.Controls.Add(this.domain);
					this.Controls.Add(this.sslIcon);
					this.Controls.Add(this.sslDescription);
					this.Controls.Add(this.reputeIcon);
					this.Controls.Add(this.regTime);
					this.Controls.Add(this.regHost);
					this.Controls.Add(this.PopDescription);

					if (this.record.Certs != null) 
					{
						this.certIcon.Location = new Point(5, 120);
						this.certIcon.Size = new Size(31, 32);
						this.certIcon.Image = Image.FromFile(@"C:\VisualStudio\PrivacyGuard\images\sitereport\certificate.gif");

						this.certDescription.Location = new Point(45, 120);
						this.certDescription.Size = new Size(WIDTH-45, 40);
						string[] certs = this.record.Certs;
						string certstr = "This site is verified by the following trusted third ";
						if (certs.Length == 1)
							certstr += "party: ";
						else 
							certstr += "parties: ";
						for (int i = 0; i < certs.Length-1; i++)
							certstr += (certs[i]+ ", ");
						certstr += certs[certs.Length-1];
						this.certDescription.Font = new Font(WebWalletInterface.FONTNAME, this.certDescription.Font.Size);
						this.certDescription.TextAlign = ContentAlignment.TopLeft;
						this.certDescription.Text = certstr;

						this.Controls.Add(this.certIcon);
						this.Controls.Add(this.certDescription);

						this.Size = new Size(WIDTH, 160);
					} 
					else 
						this.Size = new Size(WIDTH, 120);
				}
			}

			public void Shrink(int width) 
			{
				this.domain.Size = new Size(width, 25);
				this.sslDescription.Size = new Size(width-45, 40);
				this.regTime.Location = new Point(45, 75);
				this.regTime.Size = new Size(width-45, 25);
				this.regHost.Location = new Point(45, 100);
				this.regHost.Size = new Size(width-45, 25);
				this.PopDescription.Location = new Point(45, 125);
				this.PopDescription.Size = new Size(width-45, 25);
				if (this.Controls.Contains(this.certDescription)) 
				{
					this.certIcon.Location = new Point(5, 155);
					this.certDescription.Location = new Point(45, 155);
					this.certDescription.Size = new Size(width-45, 50);
					this.Size = new Size(width, 205);
				} else
					this.Size = new Size(width, 155);
			}
		}

		private IEBrowser browser;
		private Point topright;
		private string site1;
		private string site2;

		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		public SiteReportBox(IEBrowser b, string d, Point tr)
		{
			this.browser = b;
			this.site1 = d;
			this.topright = tr;
			InitializeComponent();
		}

		public SiteReportBox(IEBrowser b, string d1, string d2, Point tr)
		{
			this.browser = b;
			this.site1 = d1;
			this.site2 = d2;
			this.topright = tr;
			InitializeComponent();
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(SiteReportBox));
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);

			SiteDescription s1 = new SiteDescription(this.site1, this.browser.ReputationEvaluator.GetReputationRecord(this.site1));
			s1.Location = new Point(5, 5);
			//s1.BorderStyle = BorderStyle.FixedSingle;
			this.Controls.Add(s1);

			if (this.site2 != null) 
			{
				SiteDescription s2 = new SiteDescription(this.site2, this.browser.ReputationEvaluator.GetReputationRecord(this.site2));
				s2.Location = new Point(s1.Left+s1.Width+10, 5);
				//s2.BorderStyle = BorderStyle.FixedSingle;
				this.Controls.Add(s2);

				this.ClientSize = new Size(s1.Width+s2.Width+20, Math.Max(s1.Height, s2.Height)+10);
			} else 
				this.ClientSize = new Size(s1.Width+10, s1.Height+10);

			this.MaximizeBox = false;
			this.MinimizeBox = false;
			this.StartPosition = System.Windows.Forms.FormStartPosition.Manual;

			int top = this.topright.Y - this.Size.Height/2;
			int bottom = this.topright.Y + this.Size.Height/2;

			if (top <= 5)
				this.Location = new Point(this.topright.X-this.Size.Width, 5);
			else if (bottom >= 768-5)
				this.Location = new Point(this.topright.X-this.Size.Width, 768-5-this.Size.Height);
			else
				this.Location = new Point(this.topright.X-this.Size.Width, top);

			if (this.site2 == null)
				this.Text = "Site Report";
			else
				this.Text = "Site Report Comparison";
		}
		#endregion
	}
}
