using System;
using System.Drawing;
using System.Collections;
using System.Windows.Forms;
using mshtml;

namespace PrivacyGuard.WebWallet.WebWalletToolkit.CardToolkit
{
	/// <summary>
	/// Summary description for Card.
	/// </summary>
	public abstract class Card : System.Windows.Forms.Panel
	{
		public const int ENTRYH = 15;
		public const int INTERENTRYH = 5;
		public const int LABELW = DataInputInterface.CARDW - 10;

		public const int TITLEX = 0;
		public const int TITLEY = 0;
		public const int TITLEW = DataInputInterface.CARDW;
		public const int TITLEH = 65;

		public const int VALUEX = 0;
		public const int VALUEY = TITLEX + TITLEH;
		public const int VALUEW = TITLEW;
		public const int VALUEH = 80;

		private System.Windows.Forms.Panel titleArea;
		private System.Windows.Forms.Label title;
		protected System.Windows.Forms.Label domain;
		protected WebWalletToolkit.DomainDescription description;
		private bool isTrusted;
		public bool IsTrusted 
		{
			get 
			{
				return this.isTrusted;
			}
		}
//		private System.Windows.Forms.PictureBox rating;
		//private System.Windows.Forms.Label authscope;

		protected System.Windows.Forms.Panel valueArea;

		protected DataInputInterface parent;
		protected WebWallet.InlineProtectionToolkit.SensitiveData.LoginToken requestToken;
		protected CardToolkit.CardPageBridge bridge;
		protected IEBrowser browser;

		public Card(WebWallet.InlineProtectionToolkit.SensitiveData.LoginToken t, 
			CardToolkit.CardPageBridge g, IEBrowser b)
		{
			this.requestToken = t;
			this.bridge = g;
			this.browser = b;
			this.parent = this.browser.Webwallet.InputInterface;
		}

		public void Initialization() 
		{
			this.Location = new Point(DataInputInterface.CARDX, DataInputInterface.CARDY);
			this.Size = new Size(DataInputInterface.CARDW, DataInputInterface.CARDH);
			this.BackColor = Color.White;
			this.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;

			this.titleArea = new System.Windows.Forms.Panel();
			this.titleArea.Location = new Point(TITLEX, TITLEY);
			this.titleArea.Size = new Size(TITLEW, TITLEH);

			this.valueArea = new System.Windows.Forms.Panel();
			this.valueArea.Location = new Point(VALUEX, VALUEY);
			this.valueArea.Size = new Size(VALUEW, VALUEH);
			this.valueArea.AutoScroll = true;

			this.Controls.Add(this.titleArea);
			this.Controls.Add(this.valueArea);

			FormTitleArea();
			FormValueArea();
		}

		protected void FormTitleArea() 
		{
			this.title = new System.Windows.Forms.Label();
			this.title.Location = new System.Drawing.Point(0, 0);
			this.title.Size = new System.Drawing.Size(TITLEW, 20);
			this.title.Text = GetCardTitle();
			this.title.Font = new System.Drawing.Font(WebWallet.WebWalletInterface.FONTNAME, 9, FontStyle.Bold);
			this.title.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;

			this.domain = new System.Windows.Forms.Label();
			this.domain.Location = new Point(0, 20);
			this.domain.Size = new Size(TITLEW, 15);
//			this.domain.Size = new Size(TITLEW, 40);
			this.domain.Text = GetCardDomain();
//			this.domain.Font = new Font(WebWallet.WebWalletInterface.FONTNAME, 9, FontStyle.Bold);
			this.domain.Font = new Font(WebWallet.WebWalletInterface.FONTNAME, this.domain.Font.Size);
			this.domain.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;

			this.description = new DomainDescription(GetCardDomain());
			this.description.Location = new Point(0, 35);
			this.description.Size = new Size(TITLEW, 15);
			this.description.Text = this.browser.GetDomainDescription(GetCardDomain());
			this.description.Font = new Font(WebWallet.WebWalletInterface.FONTNAME, this.description.Font.Size);
			this.description.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			this.description.LinkClicked += new LinkLabelLinkClickedEventHandler(description_LinkClicked);
//
//			this.rating = new System.Windows.Forms.PictureBox();
//			this.rating.Location = new Point(83, 50);
//			this.rating.Size = new Size(64, 12);
//			BackEndImpl.ReputationEvaluator.ReputationRecord rr = 
//				this.browser.ReputationEvaluator.GetReputationRecord(GetCardDomain());
//			this.isTrusted = rr.IsTrustedSite();
//			this.rating.Image = 
//				Image.FromFile(rr.GetRatingImage());

			BackEndImpl.ReputationEvaluator.ReputationRecord rr = 
				this.browser.ReputationEvaluator.GetReputationRecord(GetCardDomain());
			this.isTrusted = rr.IsTrustedSite();
			if (!this.isTrusted) 
			{
				this.description.LinkColor = Color.Red;
				this.description.Font = new Font(WebWallet.WebWalletInterface.FONTNAME, this.description.Font.Size, FontStyle.Bold);
			} 
			else 
			{
				this.description.LinkColor = Color.Blue;
				this.description.Font = new Font(WebWallet.WebWalletInterface.FONTNAME, this.description.Font.Size);
			}
//			string scope = this.token.GetAuthScope();
//			if (scope.Equals(BackEndImpl.SecureStorage.DEFAULTSCOPE))
//			{
//				this.titleArea.Size = new Size(this.cardWidth, 47);
//			} 
//			else 
//			{
//				this.authscope = new System.Windows.Forms.Label();
//				this.authscope.Location = new Point(5, 50);
//				this.authscope.Size = new Size(260, 15);
//				this.authscope.Text = "Authentication Area: " + scope;
//				this.authscope.Font = new Font(WebWallet.WebWalletInterface.FONTNAME, this.authscope.Font.Size, FontStyle.Bold);
//				this.authscope.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
//
//				this.titleArea.Size = new Size(this.cardWidth, 65);
//				this.titleArea.Controls.Add(this.authscope);
//			}

			this.titleArea.Controls.Add(this.title);
			this.titleArea.Controls.Add(this.domain);
			this.titleArea.Controls.Add(this.description);
//			this.titleArea.Controls.Add(this.rating);
		}

		private void description_LinkClicked (object sender, System.Windows.Forms.LinkLabelLinkClickedEventArgs e) 
		{
			this.browser.Webwallet.ShowSiteReport(sender as DomainDescription);
		}
//		public void Input_MouseDown(object sender, System.Windows.Forms.MouseEventArgs e) 
//		{
//			System.Windows.Forms.Control c = (System.Windows.Forms.Control) sender;
//			c.DoDragDrop(c.Text, DragDropEffects.Copy | DragDropEffects.Move);
//		}

		protected abstract string GetCardTitle();
		public abstract string GetCardDomain();
		protected abstract void FormValueArea();
	}
}
