using System;
using System.Drawing;
using System.Collections;

namespace PrivacyGuard.WebWallet.WebWalletToolkit
{
	/// <summary>
	/// Summary description for LoginCardFolder.
	/// </summary>
	public class LoginCardFolder : System.Windows.Forms.ListBox
	{
		public const string NEWCARD = "New Login Card";

		private CardFolder parent;
		private WebWalletInterface webwallet;
		private IEBrowser browser;

		private string defaultSelection;
		private string currentSelection;
		public string CurrentSelection 
		{
			get 
			{
				return this.currentSelection;
			}
		}

		public LoginCardFolder(CardFolder cf)
		{
			this.parent = cf;
			this.webwallet = this.parent.ParentInterface;
			this.browser = this.webwallet.Browser;
			InitializeComponent();
		}

		private void InitializeComponent() 
		{
			this.BackColor = Color.White;
			this.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
		}

		public void UpdateDisplay() 
		{
			this.Items.Clear();
			this.currentSelection = null;
			this.Items.Add(NEWCARD);
			BackEndImpl.SecureStorage storage = this.browser.SecureStorage;
			ArrayList domains = storage.getDomains();
			IEnumerator ienum = domains.GetEnumerator();
			while (ienum.MoveNext()) 
			{
				this.Items.Add((string)ienum.Current);
			}
			GetDefaultSelection();
			((System.Windows.Forms.ListBox)this).SelectedIndexChanged += new EventHandler(LoginCardFolder_SelectedIndexChanged);
		}

		private void GetDefaultSelection() 
		{
			if (this.webwallet.InputInterface.DataSubmission == null) 
			{
				string sel = NEWCARD;
				string domainname = this.webwallet.Browser.GetDomainName(false);
				IEnumerator ienum = this.Items.GetEnumerator();
				while (ienum.MoveNext()) 
				{
					string c = ienum.Current.ToString();
					if (domainname.Equals(c)) 
					{
						sel = c;
						break;
					}
				}
				this.SelectedItem = sel;
				this.defaultSelection = sel;
//				this.SelectedItem = NEWCARD;
//				this.defaultSelection = NEWCARD;
//				this.SelectedItem = null;
//				this.defaultSelection = null;
//				this.parent.EnableClearButton(false);
//				this.parent.EnableDefaultButton(false);
			}
			else 
			{
				WebWalletToolkit.CardToolkit.Card c = this.webwallet.InputInterface.DataCard;
				if (c is WebWalletToolkit.CardToolkit.NewLoginCard)
					this.SelectedItem = NEWCARD;
				else 
				{
					this.SelectedItem = (c as WebWalletToolkit.CardToolkit.StoredLoginCard).GetCardDomain();
				}
				this.defaultSelection = this.SelectedItem.ToString();
//				this.parent.EnableClearButton(true);
//				this.parent.EnableDefaultButton(false);
			}
		}

//		public void SelectDefault() 
//		{
//			this.SelectedItem = this.defaultSelection;
//		}
//
//		public void ClearSelection() 
//		{
//			this.SelectedItem = null;
//		}

		private void LoginCardFolder_SelectedIndexChanged(object sender, System.EventArgs e) 
		{
//			if (this.SelectedItem == null) 
//			{
//				this.parent.EnableClearButton(false);
//				this.webwallet.ShowErrorInterface();
//				this.currentSelection = null;
//				return;
//			} else 
//				this.parent.EnableClearButton(true);

			string selection = this.SelectedItem.ToString();
			if (selection.Equals(this.currentSelection)) 
				return;

//			this.parent.EnableDefaultButton(!selection.Equals(this.defaultSelection));

			this.currentSelection = selection;

//			this.webwallet.HideErrorInterface();

			if (selection.Equals(NEWCARD)) 
			{
				// when there is a request and the user chooses a new card,
				// the web wallet displays:
				// 1. title
				// 2. input with new card, save prompt and ok button
				// 3. card folder
				if (this.webwallet.InputInterface.OnlyConfirm)
					this.webwallet.InputInterface.RestoreSecondaryInterfaceAsOnlyConfirm();
				this.webwallet.InputInterface.SwitchNewLoginCard();
			}
			else 
			{
				string currdomain = this.browser.GetDomainName(false);
				if (selection.Equals(currdomain)) 
				{
					// when there is a request and the user chooses the correct card,
					// the web wallet displays:
					// 1. title
					// 2. input with the stored card
					// 3. card folder
					if (this.webwallet.InputInterface.OnlyConfirm)
						this.webwallet.InputInterface.RestoreSecondaryInterfaceAsOnlyConfirm();
					this.webwallet.InputInterface.SwitchStoredLoginCard(selection);
				}
				else 
				{
					// when there is a request but the user chooses a wrong card,
					// the web wallet displays:
					// 1. title
					// 2. input's confirming
					// 3. card folder
					//this.webwallet.ShowErrorInterfacewithConfirmation(selection, currdomain);
					this.webwallet.InputInterface.ShowSecondaryInterfaceAsOnlyConfirm(selection, currdomain);
				}
			}
		}
	}
}
